Společnost Valve publikovala na svém GitLabu nákresy a schémata zapojení headsetu Steam Frame. Pro nekomerční účely.
Soutěž Pwn2Own Ireland 2026 skončila 9. října. Bezpečnostní výzkumníci získali celkem 1 262 000 dolarů na odměnách. Během soutěže bylo předvedeno zneužití 98 zero-day zranitelností. Testování zahrnovalo různé kategorie zařízení a software. Výzkumníci předváděli prakticky fungující útoky podle pravidel soutěže. Výsledky následně slouží výrobcům při přípravě oprav. Mezi pokořenými jsou: Samsung Galaxy S26, OpenAI Codex, Oracle Autonomous AI Database, Google Pixel 10, u iPhone 17 neuspěli.
Programovací jazyk Python byl vydán v nové verzi 3.15.0. Podrobný přehled novinek v aktualizované dokumentaci.
BIGWORDS.PAGE je open-source webová aplikace, která po otevření odkazu v prohlížeči vykreslí přes celou obrazovku jednoduché informační sdělení. Zpráva i její nastavení jsou uložené v části URL za znakem #, například odkaz https://bigwords.page/#abclinuxu zobrazí jako velký bílý nápis 'abclinuxu' na černém pozadí. Obsah odkazu lze upravovat i vestavěným editorem, ten umožňuje nastavovat formátování a vizuální efekty textu, časovače, QR kódy a obrázky. Zdrojový kód je dostupný pod licencí MIT na GitHubu.
V neděli 11. října proběhne rotace klíče kořenové zóny. Podruhé v historii. Ondřej Filip na blogu CZ.NIC: "Pokud je pro Vás DNS protokol spíše výzva, ale přesto spravujete nějakou síť či DNS resolver, zkuste si jednoduchý test, který připravila firma Cloudflare na této adrese. Obzvláště zbystřit byste měli, pokud uvidíte nějaká červená políčka."
Vláda Spojených států se rozhodla vyřadit americkou softwarovou společnost Microsoft a několik dalších velkých technologických podniků z programu, který umožňuje kvalifikovaným zahraničním pracovníkům získat povolení k trvalému pobytu. Oznámila to včera administrativa amerického prezidenta Donalda Trumpa. Opatření zdůvodnila rozsáhlým zneužíváním programu, který je dlouhodobě terčem kritiky ze strany Trumpových příznivců, neboť prý znevýhodňuje americké pracovníky.
Datové centrum největší ruské technologické společnosti Jandex v Rjazaňské oblasti se stalo cílem dronového útoku a zastavilo provoz. Jandexu se někdy přezdívá „ruský Google“. Provozuje nejoblíbenější internetový vyhledávač v Rusku nebo aplikace pro objednávky jídla a taxi. Využívají jej desítky milionů lidí v rusky mluvících zemích.
Francouzská společnost Mistral AI představila Mistral Large 4 (interně přezdívaný 'le Chonk', volně přeloženo 'pořádný macek'), 'open-weight multimodální hybridní instruct-and-reasoning model s architekturou granulárního MoE, nativně podporující více jak 160 jazyků'. Model má přes jeden bilión parametrů, z nichž při práci využívá 49 miliard, kontextové okno o délce milion tokenů a obrazový enkodér o 1,6 miliardách parametrů.
… více »Svobodný multiplatformní herní engine Bevy napsaný v Rustu byl vydán ve verzi 0.20. Díky 227 přispěvatelům.
Simon Long oznámil Raspberry Pi Desktop pro PC a Mac s Intelem postavený na aktualizovaném Debianu 13 Trixie. S klientem Raspberry Pi Connect pro vzdálenou správu. Ke stažení je vedle Raspberry Pi OS pro Raspberry Pi.
[jirka@amisek ~]$ dir2ogg -g6 ./hudba/folk/hapka_horacek/strazce-plamene/
01-prvni-noc-v-novem-byte.ogg
02-Otevrete-okno,aby-duse-mohla-ven.ogg
03-kdo-by-se-dival-nazpatek.ogg
04-strazce-plamene.ogg
05-vidouci-ale-nevidena.ogg
06 - Neodolatelna.ogg
07 - Na hotelu v Olomouci.ogg
08-dikuvzdani.ogg
09-snezna-sova.ogg
10-nemuzes-usnout.ogg
11 - Hlava kance.ogg
Hapka & Horacek - 2006 Strazce plamene.sfv
warez_info.nfo
www.warez-forum.biz.url
[jirka@amisek ~]$ dir2ogg -g6 ./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg
File "/usr/bin/dir2ogg", line 146
print 'INFO: %s' % msg
^
SyntaxError: invalid syntax
[jirka@amisek ~]$ dir2ogg -g6 ./hudba/folk/hapka_horacek/strazce-plamene/
File "/usr/bin/dir2ogg", line 146
print 'INFO: %s' % msg
^
SyntaxError: invalid syntax
[jirka@amisek ~]$ sudo pacman -S soundconverter
pacman: /usr/lib/libcurl.so.4: no version information available (required by /usr/lib/libalpm.so.7)
řeší se závislosti..
kontrolují se interní konflikty...
Cíle (1): soundconverter-2.0.3-1
Celková velikost ke stažení: 0,12 MiB
Celková velikost po instalaci: 1,37 MiB
Pokračovat v instalaci? [A/n] a
:: Získávají se balíčky z community...
soundconverter-2.0.... 119,3 KiB 1140K/s 00:00 [######################] 100%
(1/1) kontrola integrity balíčků [######################] 100%
(1/1) načítání balíčku [######################] 100%
(1/1) kontrola konfliktů souborů [######################] 100%
(1/1) kontrola volného místa na disku [######################] 100%
(1/1) instalace soundconverter [######################] 100%
Volitelné závislosti pro soundconverter
gstreamer0.10-base-plugins: for ogg support
[jirka@amisek ~]$ sound
soundconverter soundstretch
[jirka@amisek ~]$ soundconverter
SoundConverter 2.0.3
** Message: pygobject_register_sinkfunc is deprecated (GstObject)
using Gstreamer version: 0.10.35
using 1 thread(s)
using gio
Queue start: 1 tasks, 1 thread(s).
Queue done in 0.106s (1 tasks)
Error: Cannot overwrite source file(s)!
cancelling conversion.
^CTraceback (most recent call last):
File "/usr/bin/soundconverter", line 154, in #module#
gui_main(NAME, VERSION, GLADEFILE, files)
File "/usr/lib/soundconverter/python/soundconverter/ui.py", line 1494, in gui_main
gtk.main()
KeyboardInterrupt
[jirka@amisek ~]$ ^C
[jirka@amisek ~]$ ^C
[jirka@amisek ~]$ soundconverter
SoundConverter 2.0.3
** Message: pygobject_register_sinkfunc is deprecated (GstObject)
using Gstreamer version: 0.10.35
using 1 thread(s)
using gio
Queue start: 1 tasks, 1 thread(s).
Queue done in 0.032s (1 tasks)
Error: Cannot overwrite source file(s)!
cancelling conversion.
Error: Cannot overwrite source file(s)!
cancelling conversion.
Error: Cannot overwrite source file(s)!
cancelling conversion.
[jirka@amisek ~]$ sudo chmod 7775 ./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg
[jirka@amisek ~]$ sudo chmod 7777 ./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg
[jirka@amisek ~]$ soundconverter
SoundConverter 2.0.3
** Message: pygobject_register_sinkfunc is deprecated (GstObject)
using Gstreamer version: 0.10.35
using 1 thread(s)
using gio
Queue start: 1 tasks, 1 thread(s).
Queue done in 0.065s (1 tasks)
Error: Cannot overwrite source file(s)!
cancelling conversion.
[jirka@amisek ~]$ ogg
ogg123 oggdec oggenc ogginfo
[jirka@amisek ~]$ oggdec ./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg -o - | lame -h -b 128 - dikuvzdani.mp3"
>
> oggdec ./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg -o - | lame -h -b 128 - ./dikuvzdani.mp3"
Decoding "./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg" to "standard output"
[ 0.0%]Warning: unsupported audio format
[jirka@amisek ~]$ oggdec ./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg -o - | lame -h -b 128 - dikuvzdani.mp3"
oggdec ./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg -o - | lame -h -b 128 - ./dikuvzdani.mp3"
Decoding "./hudba/folk/hapka_horacek/strazce-plamene/08-dikuvzdani.ogg" to "standard output"
[ 0.0%]Warning: unsupported audio format
[ 0.0%][jirka@amisek ~]$
python2 dir2ogg … nebo otevři soubor /usr/bin/dir2ogg a na začátku přepiš python na python2.
pacman -Syu
Já mám taky python2 (2.7) a python3 (3.2)To samozřejmě není problém.
co znamená to spojení, evidentně nemáš aktuální systém?To nemá s verzí pythonu nic společného, jde o chybu
Myslíš tím, že by se měla aktualizovat aplikace, nebo mít jen jednu verzi pythonu?
pacman: /usr/lib/libcurl.so.4: no version information available (required by /usr/lib/libalpm.so.7)Pokud bude tazatel instalovat z Archového repozitáře, dřív nebo později to vyústí v rozbitý systém, který bude těžké opravit. Programy v Archu jsou vždy kompilované vůči knihovnám, které jsou v repozitáři a se starými, které má nainstalované, nebudou fungovat. To, že to teď jenom křičí ale stále to funguje je štěstí.
Co když aplikace, pro nový není a nebude? u mě to je gtk-recordmydesktop.Tak prostě budeš používat python 2, vzhledem k množství aplikací, které stále používají python 2 (skoro bych si troufl říct, že je to stále většina) s námi bude python 2 ještě hodně dlouhou dobu.
#!/usr/bin/python, takže je otázne, prečo sa to spúšťa cez python3.
[jirka@amisek ~]$ sudo pacman -Syu pacman: /usr/lib/libcurl.so.4: no version information available (required by /usr/lib/libalpm.so.7) :: Synchronizuje se databáze balíčků... core je aktuální extra je aktuální community je aktuální :: Spouští se aktualizace systému... :: Nahradit dbus-python za extra/python2-dbus? [A/n] a :: Nahradit farsight2 za extra/farstream? [A/n] a :: Nahradit gnupg2 za core/gnupg? [A/n] a :: Nahradit gtk-xfce-engine za extra/gtk2-xfce-engine? [A/n] a :: Nahradit kdemultimedia-kioslave za extra/kdemultimedia-audiocd-kio? [A/n] a :: Nahradit kdemultimedia-kioslave za extra/libkcddb? [A/n] a :: Nahradit kdemultimedia-kioslave za extra/libkcompactdisc? [A/n] a :: Nahradit libusb za core/libusbx? [A/n] a :: Nahradit libxfce4menu za extra/garcon? [A/n] a :: Nahradit module-init-tools za core/kmod? [A/n] a :: Nahradit procps za core/procps-ng? [A/n] a :: Nahradit pyxdg za extra/python2-xdg? [A/n] a :: Nahradit sqlite3 za extra/sqlite? [A/n] a :: Nahradit udev za core/systemd? [A/n] a :: Nahradit xfce-utils za extra/xfce4-appfinder? [A/n] a :: Nahradit xfce-utils za extra/xfce4-session? [A/n] a řeší se závislosti.. :: Existují 2 balíčky poskytující java-runtime-headless: :: Repozitář extra 1) jre7-openjdk-headless 2) openjdk6 Zadejte číslo (výchozí = 1): 1 varování: zjištěna cyklická závislost: varování: dbus-core bude nainstalován před systemd, na kterém závisí varování: zjištěna cyklická závislost: varování: java-rhino bude nainstalován před jre7-openjdk-headless, na kterém závisí kontrolují se interní konflikty... chyba: selhala příprava transakce (nelze vyřešit závislosti) :: libgsf-gnome: vyžaduje libgsf=1.14.21 [jirka@amisek ~]$
pacman -Rsdd libgsf-gnomeA potom zkus znovu:
pacman -SyuVzhledem k tomu, že ale k téhle náhradě došlo před tak dlouhou dobou, mám obavu, že budeš mít následně hodně velký problém kvůli přesunu /lib -> /usr/lib. V zásadě jakýkoli systém, který nebyl déle než asi 5 měsíců aktualizovaný je jednodušší přeinstalovat než aktualizovat.
(893/893) kontrola konfliktů souborů [######################] 100% chyba: selhalo provádění transakce (konfliktní soubory) glibc: /lib již existuje v souborovém systému filesystem: /etc/mtab již existuje v souborovém systému filesystem: /var/run již existuje v souborovém systému jre7-openjdk-headless: /etc/profile.d/jre.csh již existuje v souborovém systému jre7-openjdk-headless: /etc/profile.d/jre.sh již existuje v souborovém systému Vyskytly se chyby, žádné balíčky nebyly aktualizovány.
[jirka@amisek ~]$ sudo yaourt pacman
pacman: /usr/lib/libcurl.so.4: no version information available (required by /usr/lib/libalpm.so.7)
error: no operation specified (use -h for help)
/usr/bin/pacman: /usr/lib/libcurl.so.4: no version information available (required by /usr/lib/libalpm.so.7)
pacman: /usr/lib/libcurl.so.4: no version information available (required by /usr/lib/libalpm.so.7)
1 core/pacman 4.0.3-3 [installed] (base) [nainstalovaný]
A library-based package manager with dependency support
pacman: /usr/lib/libcurl.so.4: no version information available (required by /usr/lib/libalpm.so.7)
2 core/pacman-mirrorlist 20120626-1 [20111026-1 installed]
Arch Linux mirror list for use by pacman
3 extra/namcap 3.2.4-1
A Pacman package analyzer
4 extra/srcpac 0.10.9-1
The pacman from-source wrapper
5 community/expac 1-1
pacman database extraction utility
6 community/pacman-contrib 4.0.3-1
Utilities for use with the pacman package manager
7 community/pacmatic 20120818-1
A pacman wrapper to avoid bricking your system and such other surprises.
8 community/perl-cpanplus-dist-arch 1.23-1
CPANPLUS backend for building Archlinux pacman packages
9 community/pkgfile 4-1
a pacman .files metadata explorer
10 community/reflector 2012.7.26-1
A Python 3 module and script to retrieve and filter the latest Pacman mirror list.
11 community/xpacman 0.11-6
X pacman game (use z x / ' q keys)
12 community/xpacman2 1.002-4
another X pacman game
==> Enter n° (separated by blanks, or a range) of packages to be installed
==> ----------------------------------------------
==>
[root@amisek jirka]# rm -rf /var/run /var/lock && pacman -Sf filesystem bash: pacman-color: příkaz nenalezen
# Check for an interactive session [ -z "$PS1" ] && return alias ls='ls --color=auto' PS1='[\u@\h \W]\$ ' #alias pacman='pacman-color' #setxkbmap vok czech #Startx po prihlaseni na prvni konzoli a neni-li jiz bezici #if [[ -z "$DISPLAY" ]] && [[ $(tty) = /dev/tty1 ]]; then #startx & #fi if [[ -z "$DISPLAY" ]]; then sh ~/.muj_start fi ./.bashrc (END)
[root@amisek jirka]# rm /etc/profile.d/locale.sh [root@amisek jirka]# pacman -Su --ignore glibc pacman: /usr/lib/libcurl.so.4: no version information available (required by /usr/lib/libalpm.so.7) :: Spouští se aktualizace systému... :: Nahradit dbus-python za extra/python2-dbus? [A/n] a :: Nahradit farsight2 za extra/farstream? [A/n] a varování: glibc: ignoruje se aktualizace balíčku (2.16.0-1 => 2.16.0-4) :: Nahradit gnupg2 za core/gnupg? [A/n] a :: Nahradit gtk-xfce-engine za extra/gtk2-xfce-engine? [A/n] a :: Nahradit kdemultimedia-kioslave za extra/kdemultimedia-audiocd-kio? [A/n] a :: Nahradit kdemultimedia-kioslave za extra/libkcddb? [A/n] a :: Nahradit kdemultimedia-kioslave za extra/libkcompactdisc? [A/n] a :: Nahradit libusb za core/libusbx? [A/n] a :: Nahradit libxfce4menu za extra/garcon? [A/n] a :: Nahradit module-init-tools za core/kmod? [A/n] a :: Nahradit procps za core/procps-ng? [A/n] a :: Nahradit pyxdg za extra/python2-xdg? [A/n] a :: Nahradit sqlite3 za extra/sqlite? [A/n] a :: Nahradit udev za core/systemd? [A/n] a :: Nahradit xfce-utils za extra/xfce4-appfinder? [A/n] a :: Nahradit xfce-utils za extra/xfce4-session? [A/n] a řeší se závislosti.. :: Existují 2 balíčky poskytující java-runtime-headless: :: Repozitář extra 1) jre7-openjdk-headless 2) openjdk6 Zadejte číslo (výchozí = 1): 1 varování: zjištěna cyklická závislost: varování: dbus-core bude nainstalován před systemd, na kterém závisí varování: zjištěna cyklická závislost: varování: java-rhino bude nainstalován před jre7-openjdk-headless, na kterém závisí kontrolují se interní konflikty... chyba: selhala příprava transakce (nelze vyřešit závislosti) :: libgsf-gnome: vyžaduje libgsf=1.14.21 [root@amisek jirka]#
[root@amisek jirka]# pacman -Su :: Spouští se aktualizace systému... řeší se závislosti.. kontrolují se interní konflikty... Cíle (1): glibc-2.16.0-4 Celková velikost po instalaci: 34,04 MiB Odhadovaná velikost aktualizace: 0,09 MiB Pokračovat v instalaci? [A/n] a (1/1) kontrola integrity balíčků [#####################################] 100% (1/1) načítání balíčku [#####################################] 100% (1/1) kontrola konfliktů souborů [#####################################] 100% chyba: selhalo provádění transakce (konfliktní soubory) glibc: /lib již existuje v souborovém systému Vyskytly se chyby, žádné balíčky nebyly aktualizovány. [root@amisek jirka]#
find /lib -exec pacman -Qo -- {} +
a pošli sem výpis.
[jirka@amisek ~]$ find /lib -exec pacman -Qo -- {} +
error: cannot determine ownership of directory '/lib'
/lib/libthread_db-1.0.so is owned by glibc 2.16.0-1
/lib/libSegFault.so is owned by glibc 2.16.0-1
/lib/libnss_nis.so.2 is owned by glibc 2.16.0-1
/lib/libcidn-2.16.so is owned by glibc 2.16.0-1
/lib/libcidn.so.1 is owned by glibc 2.16.0-1
/lib/libnss_dns.so.2 is owned by glibc 2.16.0-1
/lib/libanl-2.16.so is owned by glibc 2.16.0-1
/lib/ld-linux.so.2 is owned by glibc 2.16.0-1
/lib/librt-2.16.so is owned by glibc 2.16.0-1
/lib/libc.so.6 is owned by glibc 2.16.0-1
/lib/libnsl-2.16.so is owned by glibc 2.16.0-1
/lib/libthread_db.so.1 is owned by glibc 2.16.0-1
/lib/libnss_files-2.16.so is owned by glibc 2.16.0-1
/lib/libnss_hesiod.so.2 is owned by glibc 2.16.0-1
/lib/libnsl.so.1 is owned by glibc 2.16.0-1
/lib/libanl.so.1 is owned by glibc 2.16.0-1
/lib/libBrokenLocale.so.1 is owned by glibc 2.16.0-1
error: No package owns /lib/libflashplayer.so
/lib/libcrypt.so.1 is owned by glibc 2.16.0-1
/lib/libnss_db.so.2 is owned by glibc 2.16.0-1
/lib/libnss_nisplus.so.2 is owned by glibc 2.16.0-1
/lib/libresolv.so.2 is owned by glibc 2.16.0-1
/lib/libc-2.16.so is owned by glibc 2.16.0-1
/lib/libnss_files.so.2 is owned by glibc 2.16.0-1
/lib/libnss_nis-2.16.so is owned by glibc 2.16.0-1
/lib/libnss_compat.so.2 is owned by glibc 2.16.0-1
/lib/libpthread-2.16.so is owned by glibc 2.16.0-1
/lib/libdl-2.16.so is owned by glibc 2.16.0-1
/lib/libresolv-2.16.so is owned by glibc 2.16.0-1
/lib/libdl.so.2 is owned by glibc 2.16.0-1
/lib/libutil.so.1 is owned by glibc 2.16.0-1
/lib/libpthread.so.0 is owned by glibc 2.16.0-1
/lib/libutil-2.16.so is owned by glibc 2.16.0-1
/lib/libpcprofile.so is owned by glibc 2.16.0-1
/lib/libmemusage.so is owned by glibc 2.16.0-1
/lib/libnss_hesiod-2.16.so is owned by glibc 2.16.0-1
/lib/libnss_compat-2.16.so is owned by glibc 2.16.0-1
/lib/libnss_nisplus-2.16.so is owned by glibc 2.16.0-1
/lib/libnss_db-2.16.so is owned by glibc 2.16.0-1
/lib/librt.so.1 is owned by glibc 2.16.0-1
/lib/libnss_dns-2.16.so is owned by glibc 2.16.0-1
/lib/libm.so.6 is owned by glibc 2.16.0-1
error: cannot determine ownership of directory '/lib/udev'
error: cannot determine ownership of directory '/lib/udev/rules.d'
/lib/udev/rules.d/90-hal.rules is owned by hal 0.5.14-4
/lib/libcrypt-2.16.so is owned by glibc 2.16.0-1
/lib/libm-2.16.so is owned by glibc 2.16.0-1
/lib/ld-2.16.so is owned by glibc 2.16.0-1
/lib/libBrokenLocale-2.16.so is owned by glibc 2.16.0-1
[jirka@amisek ~]$
/lib/libflashplayer.soA pomocí pacmana odstraň hal (ten už je taky nějaký ten pátek zahozený):
pacman -Rs halTeď už by aktualizace měla projít.
A ještě taková drobnost. Přestal mi fungovat flash plugin pro prohlížeč.Ten flash jsi tam dával ručně? Flash v /lib nemá co dělat. Nainstaluj ho normálně přes pacmana, balíček flashplugin.
Jak tak sleduju tuto diskusi, tak by možná pro tebe byla lehčí reinstalace.
Nemusíš "formátovat" (přesněji: vytvářet znovu souborový systém). Stačí ručně např. pomocí rm (z live distribuce) odstranit nepotřebné a potom reinstalovat (neformátovat!). Doporučuju instalovat pomocí aktuálního instalačního obrazu.
Nyní už nefunguje nic.A co jsi čekal? Je mi to líto, ale tohle byla ta největší blbost, co jsi mohl udělat. Kdybys jen odstranil těch pár souborů, jak jsem zmiňoval výše, upgrade glibc by už s velkou pravděpodobností prošel bez problémů.
existuje možnost jak z instal cd z r.2008 nainstalovat znova glibc?Jestli je to CD z roku 2008 tak by sis tím asi moc nepomohl, za tu dobu se toho hodně změnilo a nejspíš bys taky nic nespustil. Každopádně opravit to jde, ale bude to ještě těžší než předtím. Můžeš stáhnout nové install CD, v něm připojit současný systém a pomocí
pacman -S glibc -r /cesta/k/pripojenemu/systemu tam glibc nainstalovat.
mkdir /mnt/hdd/
mount /dev/sda/ /mnt/hdd/
pacman -S ....... /mnt/hdd/Hlaska nemohu najit a psat do /mnt/hdd/
chmod 7777 /mnt/hdd/
pacman -S ........Stejna chybova hlaska.
mkdir -p /mnt/hdd ; mount -t auto /dev/sdax /mnt/hdd ; pacman -S glibc -r /mnt/hdd
Neopisuj slepě, co jsem zde napsal! Např. "sdax" je třeba nahradit za "sda1" apod.
Nezapomeň nakonec: umount /mnt/hdd
swap a home -- ty teď nebudeš potřebovat. Nás zajímá oddíl, který připojuješ do / (tedy do kořenového adresáře). Myslím, že jeden z oddílů bude oddíl, nak kterém se nachází jádro, grub... tedy oddíl připojovaný do /boot
Pokud neuvedeš přesné kroky, jak jsi postupoval (kde to selhalo) -- těžko ti někdo poradí.
mkdir -p /mnt/hdd mount -t auto /dev/sdax /mnt/hdd mount -t auto /dev/sday /mnt/hdd/var pacman -S glibc -r /mnt/hddKde sday je oddíl, na kterém je /var.
[jirka@amisek ~]$ chromium [973:984:308405132:ERROR:object_proxy.cc(495)] Failed to call method: org.freedesktop.DBus.Properties.Get: object_path= /org/freedesktop/NetworkManager: org.freedesktop.DBus.Error.Spawn.ChildExited: Launch helper exited with unknown return code 1 [973:973:308455798:ERROR:process_singleton_linux.cc(907)] Failed to create socket directory. [973:973:308456340:ERROR:chrome_browser_main.cc(1552)] Failed to create a ProcessSingleton for your profile directory. This means that running multiple instances would start multiple browser processes rather than opening a new window in the existing process. Aborting now to avoid profile corruption.
Seš si jistý, že ti běží dbus? Tzn. v /etc/rc.conf máš:
DAEMONS=(hwclock syslog-ng dbus network crond avahi-daemon cupsd)
Dále v ~/.xinitrc by mělo být něco takového:
source /etc/X11/xinit/xinitrc.d/30-dbus
[jirka@amisek ~]$ less /etc/rc.conf [jirka@amisek ~]$ sudo /etc/rc.d/dbus restart :: Stopping D-BUS system messagebus [DONE] :: Starting D-BUS system messagebus [DONE] [jirka@amisek ~]$A to druhy, to jsem tam nikdy nemel (jen pozn.) ma to byt pred nebo za exec xfce4-session A nemel by byt kazdy radek ukoncen ; ??
ma to byt pred nebo za
Před.
A nemel by byt kazdy radek ukoncen ; ??
To snad bylo u Pascalu, ne? Tohle je shell. Takže oddělovačem může být i konec rádky.
Poznámka: Pokud máš v ~/xinitrc toto:
if [ -d /etc/X11/xinit/xinitrc.d ]; then
for f in /etc/X11/xinit/xinitrc.d/*; do
[ -x "$f" ] && . "$f"
done
unset f
fi
tak předchozí radu ignoruj.
#!bin/sh source /etc/X11/xinit/xinitrc.d/30-dbus #nepomohlo exec xfce4-session ./.xinitrc (END)
/etc/X11/xorg.conf zpravidla není třeba, já osobně ho nemám.
[jirka@amisek ~]$ ls /etc/X11/ twm xinit xorg.conf.zaloha xorg.conf_z xdm xorg.conf.d xorg.conf.zaloha_stara [jirka@amisek ~]$ ls /etc/X11/xorg.conf. xorg.conf.d/ xorg.conf.zaloha xorg.conf.zaloha_stara [jirka@amisek ~]$ ls /etc/X11/xorg.conf.d/ 10-evdev.conf 10-quirks.conf [jirka@amisek ~]$
Já osobně rozložení klávesnice nastavuju pomocí programu setxkbmap
Tedy např.: setxkbmap cz
Tiskni
Sdílej: